/**
 * @packageDocumentation
 * @module Sub-Screens
 */
import React from 'react';
/**
 * Type to represent the input of the account details component.
 *
 * @param firstName  The first name string.
 * @param lastName  The last name string.
 */
export declare type AccountDetailInformation = {
    firstName: string;
    lastName: string;
};
/**
 * Defaults for the account details component inputs.
 */
export declare const emptyAccountDetailInformation: {
    firstName: string;
    lastName: string;
};
/**
 * Handle the change of any of the account details inputs.
 *
 * @param onDetailsChanged   Handle the change of any of the account details inputs.
 * @param onSubmit callback called when user submits on the last form field to advance the screen
 * @param theme (Optional) react-native-paper theme partial for custom styling.
 */
export declare type AccountDetailsProps = {
    onDetailsChanged(details: AccountDetailInformation | null): void;
    onSubmit?: () => void;
    theme?: ReactNativePaper.Theme;
};
/**
 * Renders the content of the Account Details screen entry
 * (inputs for first name, last name, and phone number).
 *
 * @category Component
 */
export declare const AccountDetails: React.FC<AccountDetailsProps>;
