/**
 * @packageDocumentation
 * @module Sub-Screens
 */
import React from 'react';
/**
 * Handle the change of the password input.
 *
 * @param eulaAccepted  (Optional) If the EULA has been accepted or not. Default false.
 * @param eulaContent  (Optional) The content of the EULA.
 * @param onEulaChanged  The function to handle when the EULA state has changed.
 * @param eulaError  The error message.
 * @param loadEula  The function to be used for loading the EULA.
 * @param htmlEula (Optional) whether the EULA should be plaintext or support HTML
 * @param theme (Optional) react-native-paper theme partial for custom styling.
 */
declare type EulaProps = {
    eulaAccepted?: boolean;
    eulaContent?: string;
    onEulaChanged(accepted: boolean): void;
    eulaError: string | null;
    loadEula: () => void;
    htmlEula?: boolean;
    theme?: ReactNativePaper.Theme;
};
/**
 * Renders the content of the EULA screen (EULA body and accept checkbox).
 *
 * @category Component
 */
export declare const Eula: React.FC<EulaProps>;
export {};
