/**
 * @packageDocumentation
 * @module Sub-Screens
 */
import React from 'react';
/**
 * Properties for the verify email component.
 *
 * @param initialCode  value used to initialize the code.
 * @param onVerifyCodeChanged  Handle the verify code change action. Called each time the code changes.
 * @param onResendVerificationEmail  Handle the press of the resend verification email.
 * @param onSubmit callback called when user submits on the last form field to advance the screen
 * @param theme (Optional) react-native-paper theme partial for custom styling.
 */
declare type VerifyEmailProps = {
    initialCode?: string;
    onVerifyCodeChanged(code: string): void;
    onResendVerificationEmail(): void;
    onSubmit?: () => void;
    theme?: ReactNativePaper.Theme;
};
/**
 * Renders the content of the verify email screen for self-registration
 * (input for verification code and button to resend code).
 *
 * @category Component
 */
export declare const VerifyEmail: React.FC<VerifyEmailProps>;
export {};
